@@ -1,5 +1,5 @@
 package Dancer2;
-$Dancer2::VERSION = '0.300000';
+$Dancer2::VERSION = '0.300001';
 # ABSTRACT: Lightweight yet powerful web application framework
 
 use strict;
@@ -128,7 +128,7 @@ Dancer2 - Lightweight yet powerful web application framework
 
 =head1 VERSION
 
-version 0.300000
+version 0.300001
 
 =head1 DESCRIPTION
 
@@ -292,6 +292,7 @@ We are also on IRC: #dancer on irc.perl.org.
     dtcyganov
     Erik Smit
     Fayland Lam
+    ferki
     Gabor Szabo
     geistteufel
     Gideon D'souza
@@ -335,6 +336,7 @@ We are also on IRC: #dancer on irc.perl.org.
     Matt S Trout
     Maurice
     MaxPerl
+    Ma_Sys.ma
     Menno Blom
     Michael Kröll
     Michał Wojciechowski
@@ -370,6 +372,7 @@ We are also on IRC: #dancer on irc.perl.org.
     Snigdha
     Steve Dondley
     Tatsuhiko Miyagawa
+    Timothy Alexis Vass
     Tina Müller
     Tom Hukins
     Upasana Shukla
@@ -387,7 +390,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Alexis Sukrieh.
+This software is copyright (c) 2020 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
