@@ -1,6 +1,6 @@
 package Dancer2::Core::Role::SessionFactory::File;
 # ABSTRACT: Role for file-based session factories
-$Dancer2::Core::Role::SessionFactory::File::VERSION = '0.300000';
+$Dancer2::Core::Role::SessionFactory::File::VERSION = '0.300001';
 use Moo::Role;
 with 'Dancer2::Core::Role::SessionFactory';
 
@@ -125,7 +125,7 @@ Dancer2::Core::Role::SessionFactory::File - Role for file-based session factorie
 
 =head1 VERSION
 
-version 0.300000
+version 0.300001
 
 =head1 DESCRIPTION
 
@@ -138,13 +138,14 @@ serialization and deserialization.
 Classes consuming this must satisfy three requirements: C<_suffix>,
 C<_freeze_to_handle> and C<_thaw_from_handle>.
 
-    package Dancer2::SessionFactory::XYX
+    package Dancer2::Session::XYX;
 
+    use Dancer2::Core::Types;
     use Moo;
 
     has _suffix => (
         is      => 'ro',
-        isa     => 'Str',
+        isa     => Str,
         default => sub { '.xyz' },
     );
 
@@ -181,7 +182,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Alexis Sukrieh.
+This software is copyright (c) 2020 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
